@@ -7,7 +7,7 @@ import argparse
 import os
 import subprocess
 import urllib.request, urllib.error, urllib.parse
-from . import utils
+from lib import utils
 import sys
 from shutil import copyfile
 from .agent import run_agent
