@@ -15,8 +15,8 @@ import sys
 import yaml
 from os.path import join
 from time import sleep
-from agentinit import init__configuration
-from taskmanager import TaskManager
+from lib.agentinit import init__configuration
+from lib.taskmanager import TaskManager
 
 
 def run_agent(debug=False, verbose=True):
